@@ -10,5 +10,5 @@ pydocstyle datacite && \
 isort -rc -c -df **/*.py && \
 check-manifest --ignore ".travis-*" && \
 sphinx-build -qnNW docs docs/_build/html && \
-python setup.py test && \
+pytest tests && \
 sphinx-build -qnNW -b doctest docs docs/_build/doctest
