@@ -15,9 +15,9 @@ from __future__ import absolute_import, print_function
 import socket
 import ssl
 
-import httpretty
 import pytest
 from helpers import APIURL, get_client
+from httpretty_mock import httpretty
 from mock import patch
 from requests import ConnectionError
 
